pub enum Message {
PlainJson {
header: DidCommHeader,
body: String,
},
SignedJson {
sender: Did,
header: DidCommHeader,
body: String,
},
AnonCryptJson {
header: DidCommHeader,
body: String,
},
AuthCryptJson {
sender: Did,
header: DidCommHeader,
body: String,
},
}Expand description
DIDComm Message Envelope
See: https://identity.foundation/didcomm-messaging/spec/v2.1/#iana-media-types
Variants
PlainJson
Unsiged JSON encoded message.
Envelope: plaintext (no envelope)
Media Type: application/didcomm-plain+json
SignedJson
Signed JSON encoded message.
The identity has been verified when this is constructed.
Envelope: signed(plaintext)
Media Type: application/didcomm-signed+json
AnonCryptJson
Encrypted JSON encoded message.
Guarantees confidentiality and integrity without revealing the identity of the sender.
Envelope: anoncrypt(plaintext)
Media Type: application/didcomm-encrypted+json
AuthCryptJson
Encrypted authenticated JSON encoded message.
Guarantees confidentiality and integrity. Also proves the identity of the sender – but in a way that only the
recipient can verify. This is the default wrapping choice, and SHOULD be used unless a different goal is
clearly identified. By design, this combination and all other combinations that use encryption in their
outermost layer share an identical IANA media type, because only the recipient should care about the
difference. Media Type: application/didcomm-encrypted+json
The identity has been verified when this is constructed.
Envelope: authcrypt(plaintext)
Media Type: application/didcomm-encrypted+json
Implementations
Sourceimpl Message
impl Message
Sourcepub async fn receive<I, P>(
sender_resolver: I,
recipent_resolver: P,
data: &[u8],
) -> Result<Message, ReceiveError>where
I: IdentityResolver + Send + Sync + 'static,
P: PrivateIdentityResolver + Send + Sync + 'static,
pub async fn receive<I, P>(
sender_resolver: I,
recipent_resolver: P,
data: &[u8],
) -> Result<Message, ReceiveError>where
I: IdentityResolver + Send + Sync + 'static,
P: PrivateIdentityResolver + Send + Sync + 'static,
Receive message from data.
Sourcepub fn header(&self) -> &DidCommHeader
pub fn header(&self) -> &DidCommHeader
Return message header.
Sourcepub fn body_deserialize<T: DeserializeOwned>(&self) -> Result<T, Error>
pub fn body_deserialize<T: DeserializeOwned>(&self) -> Result<T, Error>
Try to deserialize message to T.
Sourcepub fn is_validated_sender(&self) -> bool
pub fn is_validated_sender(&self) -> bool
Test if message is validated.
pub fn into_inner(self) -> (DidCommHeader, String)