pub struct PeerDidCommHeader {
pub from_peer_id: Option<String>,
pub header: DidCommHeader,
}Fields
from_peer_id: Option<String>OPTIONAL. The PeerId encoded as a string of the producer of the message. This is used to verifiable correlate a Did and a PeerId.
header: DidCommHeaderHeader.