pub struct VerificationMethod {
pub id: String,
pub method_type: VerificationMethodTypes,
pub controller: String,
pub public_key_jwk: Option<Jwk>,
pub public_key_multibase: Option<String>,
pub public_key_base58: Option<String>,
pub public_key_hex: Option<String>,
}Expand description
Verification Method. See: https://www.w3.org/TR/did-core/#verification-methods
Fields
id: StringThe value of the id property for a verification method MUST be a string that conforms to the rules in Section 3.2 DID URL Syntax.
method_type: VerificationMethodTypesThe value of the type property MUST be a string that references exactly one verification method type. In order to maximize global interoperability, the verification method type SHOULD be registered in the DID Specification Registries [DID-SPEC-REGISTRIES].
controller: StringThe value of the controller property MUST be a string that conforms to the rules in 3.1 DID Syntax.
public_key_jwk: Option<Jwk>The publicKeyJwk property is OPTIONAL. If present, the value MUST be a map representing a JSON Web Key that conforms to [RFC7517]. The map MUST NOT contain “d”, or any other members of the private information class as described in Registration Template. It is RECOMMENDED that verification methods that use JWKs [RFC7517] to represent their public keys use the value of kid as their fragment identifier. It is RECOMMENDED that JWK kid values are set to the public key fingerprint [RFC7638]. See the first key in Example 13 for an example of a public key with a compound key identifier.
public_key_multibase: Option<String>The publicKeyMultibase property is OPTIONAL. This feature is non-normative. If present, the value MUST be a string representation of a [MULTIBASE] encoded public key.
public_key_base58: Option<String>This property is deprecated in favor of publicKeyMultibase or publicKeyJwk. It’s generally expected that this term will still be used in older suites and therefore needs be supported for legacy compatibility, but is expected to not be used for newly defined suites.
public_key_hex: Option<String>This property is deprecated in favor of publicKeyMultibase or publicKeyJwk. It’s generally expected that this term will still be used in older suites and therefore needs be supported for legacy compatibility, but is expected to not be used for newly defined suites.
Implementations